# netdata-pandas
> A helper library to pull data from netdata api into a pandas dataframe.


[![pypi package](https://img.shields.io/pypi/v/netdata-pandas.svg)](https://pypi.python.org/pypi/netdata-pandas/)

## Install

`pip install netdata-pandas`

## Quickstart

Fill me in please! Don't forget code examples:

```python
1+1+2
```




    4


